pycocoa.octypes.Allocator_t

Package pycocoa :: Module octypes :: Class Allocator_t |
[frames] | no frames]

# Class Allocator_t

          object --+
                   |
           ??._CData --+
                       |
    _ctypes._SimpleCData --+
                           |
             ctypes.c_void_p --+
                               |
                          ObjC_t --+
                                   |
                                  Allocator_t

ObjC `CFAllocatorRef` type.

Instance Methods
Inherited from `ObjC_t`: `__repr__`, `__str__` Inherited from `ctypes.c_void_p`: `from_param` Inherited from `_ctypes._SimpleCData`: `__ctypes_from_outparam__`, `__init__`, `__new__`, `__nonzero__` Inherited from `_CData`: `__hash__`, `__reduce__`, `__setstate__` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Properties
Inherited from `ObjC_t`: `typename` Inherited from `_ctypes._SimpleCData`: `value` Inherited from `object`: `__class__`